/*
dos_serial.c

Sean Bailey  (baileys@cdr.stanford.edu)
Stanford Biomimetics Robotics Lab  (cdr.stanford.edu/biomimetics)

This program was used to test the serial port in DOS.  The key
to making it work seems to be sending bits 6 and 8 high
(> 3 Volts, which can be achieved by just hooking up a 9 volt
battery, with the negative attached to pin 5 of course (ground)).
Then communication commences over pin 3 (signal) and pin 5
(ground).

I use the header bios.h (which seems to be the same in Borland
C++ and Microsoft C++) and the command _bios_serialcom (see web
or manual for details).

This program in particular initially asks for a port, and then
prompts for numbers to be sent to that port, with the given
communication parameters.

*/

#include <stdio.h>
#include <stdlib.h>
#include <bios.h>

int main(void)  {
   int serial_port, number_to_send, return_byte;

	//Intro and warning
	printf( "\nSimple DOS serial port testing program.\n" );
   printf( "Sean Bailey (baileys@cdr.stanford.edu)\n\n" );
   printf( "Uses the bios.h command _bios_serialcom, with 8 data bits,\n" );
   printf( "one stop bit, no parity, and 9600 baud (all easy to change in\n" );
   printf( "source code).\n\n" );
   printf( "Exit by pressing CTRL-c or else you will have to reboot\n" );
	printf( "to get the serial port working again.\n" );
   printf( "Press return if you understand this.\n" );
   getchar();

   //Select serial port
	printf( "\nSelect a serial port:\n" );
   printf( "1) COM 1\n" );
   printf( "2) COM 2\n" );
   printf( "3) COM 3\n" );
   printf( "4) COM 4\n" );
   scanf( "%d", &serial_port );
   printf( "Serial port %d selected.\n", serial_port );
	serial_port--;  //so it's 0-3 instead of 1-4 for _bios_serialcom

   //Open serial port for communications
	printf( "\nInitializing.\n" );
   return_byte = _bios_serialcom( _COM_INIT, serial_port,
   	_COM_CHR8 | _COM_NOPARITY | _COM_STOP1 | _COM_9600 );
   printf("Init status: 0x%4.4X\n\n", return_byte );

   //Loop, prompting for a number to send to the serial port
	while( 1 )  {
      printf( "Enter a number to send to the serial port: " );
      scanf( "%d", &number_to_send );
      printf( "Number to send: %d\n", number_to_send );
    	return_byte = _bios_serialcom( _COM_SEND, serial_port, number_to_send );
     	printf( "Send status: 0x%4.4X\n\n", return_byte );
   }

   //Never gets here, but why not
   return( 1 );

}